
from .rpcclient import SeafileRpcClient as RpcClient

class TaskType(object):
    DOWNLOAD = 0
    UPLOAD = 1
